{% load i18n %}
{% if not spec.is_placeholder_title %}
    <h3>{% blocktrans with filter_title=title %} By {{ filter_title }} {% endblocktrans %}</h3>
{% endif %}
    <ul>
        <li>{{ spec.rendered_widget }}</li>
    </ul>
<script>
    (function($) {
        $(document).ready(function () {
            $('#changelist-filter select[name={{ spec.parameter_name }}]').on(
                'change',
                function (e, choice) {
                    var val = $(e.target).val() || '';
                    window.location.search = search_replace('{{ spec.parameter_name }}', val);
                });
        });
    })(yl.jQuery);
</script>
